#!perl -w
#
# admiral 
# 19/01/2002
#
# 

package CGI::Bus::lngbase::CGI_Bus_tm_ru; # Language base
use CGI::Bus::lngbase::CGI_Bus_tm;
use strict;

1;

sub lngbase {
 my @msg =CGI::Bus::lngbase::CGI_Bus_tm::lngbase;
 push @msg,
 (-nap=>['',     '孨 ஢']
 ,-nup=>['',     '襫騩 ஢']
 ,-nth=>['',    ' ਫ -㬮砭']
 ,-bck=>['',    '  ।饬 ࠭']
 ,-lgn=>['',    '  ⥬']
 ,-lst=>['',     '  ᮣ᭮ ᫮ 롮ન (᪠)']
 ,-lsr=>['',     ' ᯨ᮪ ᥩ']
 ,-qry=>['',   '᫮ 롮ન (᪠) ᥩ']
 ,-crt=>['',  '  , ⮡ ⥬ \'⠢\'    ']
 ,-sel=>['',  '()    ,  ']
 ,-edt=>['',   '४⥫ ᬮ / ।஢ ']
 ,-frm=>['',     '१㧨  ᬮ ,  ']
 ,-upd=>['࠭','     , ࠭  ⮩ ']
 ,-del=>['',  '     ']
 ,-ins=>['⠢', '⠢     ']
 ,-hlp=>['ࠢ',  ' ࠭ ࠢ']

 ,'op!let' =>['',    '⢨ \'$_\' 饭']
 ,'!constr'=>['',    '襭 ࠭祭']

 ,'Help'      =>['ࠢ',         '']
 ,'Lists'     =>['।⠢ (᪨)','।⠢, ᪨   ᥩ, ।  ਫ']
 ,'Fields'    =>['',            ' , ।  ਫ']
 ,'Commands'  =>['',         ',   ᯮ짮']
 );
 @msg
}


